# Penrose Python

![assets/img/penrose-logo.png](assets/img/penrose-logo.png)

This is a Python Library to interact with the Penrose API. It provides an executable
and container for interacting with the [Penrose Library](https://www.github.com/penrose-lib).

**under development**

## Contributing
We have many ways to contribute, and will briefly provide resources here to get you started.

### How to Contribute
If you are a developer interested in working on Penrose, you should read out [contributing guidelines](.github/CONTRIBUTING.md) for details.

### Code of Conduct
It's important to treat one another with respect and maintain a fun and respectful environment for the open source community. Toward this aim, we ask that you review our [code of conduct](.github/CODE_OF_CONDUCT.md)
